##########
pydivide
##########

Pydivide is a python package which allows the user to quickly plot MAVEN key parameter data.  This toolkit uses the "pytplot" library.     

Pydivide can be used in python scripts, or interactively through IPython and the Jupyter notebook.  

Install Python
=============

You will need Python version 3.5 to run pydivide.  

It is recommended that you install `Anaconda <https://www.continuum.io/downloads/>`_, as it comes with a suite of packages that are useful for data science. 

You could also install python directly from `python.org <https://www.python.org/download/>`_.

Install pydivide
=============

Open up a terminal, and type::

	pip install pydivide
	
This will install pydivide and all of it's dependencies.  

Running Pydivide
=============

To start using pytplot in a similar manner to IDL tplot, start up an interactive environment through the terminal command::

	ipython 
	
or, if you prefer the jupyter interactive notebook::

	jupyter notebook
	
then, just import the package by typing the command::

	import pydivide

A demo/tutorial can be found here: `docs/pytplot_tutorial.html <http://htmlpreview.github.com/?https://github.com/MAVENSDC/Pydivide/blob/master/docs/pydivide_tutorial.html>`_.
	
	
Contact
=============

If you have any suggestions or notice any problems, don't hesitate to contact Bryan Harter: harter@lasp.colorado.edu 